package com.ruoyi.system.domain;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;

import java.util.Date;

/**
 * 导入表的清晰表 act_supplies_import_cleaning
 * 
 * @author
 * @date 2023-12-15
 */
public class ActSuppliesImportCleaningAcc extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    /** 导入表的清洗ID */
    @Excel(name = "导入表的清洗ID")
    private String id;


    /**所属规则*/
    @Excel(name = "所属矿id",readConverterExp = "1、东欢坨矿 2、范矿 3、林西矿 4、吕矿 5、钱家营矿 6、唐山矿 7、宏丰 8、云飞 9、平安")
    private String sskId;

    /** 日期(年月)*/
    private String hdate;

    /** 历史表ID*/
    private Long hId;

    private String kmCode;

    private String yyUuid;

    /** 所在行*/
    private String HeaderRow;
    /** 物料名称*/
    private String nameColumn;
    /** 物料编码*/
    private String codeColumn;
    /** 部门*/
    private String departmentColumn;
    /** 数量*/
    private String numberColumn;
    /** 单价*/
    private String moneyColumn;
    /** 金额*/
    private String moneyColumns;
    /** 导入表内日期*/
    private String dateColumn;
    /** 费用来源*/
    private String sOfExpenses;
    /** 32类分类*/
    private String categories;
    /**
     * 型号
     */
    private String model;
    /**
     * 单位
     */
    private String unit;
    /**
     * 总金额
     */
    private String money;

    public String getMoney() {
        return money;
    }

    public void setMoney(String money) {
        this.money = money;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public String getsOfExpenses() {
        return sOfExpenses;
    }

    public void setsOfExpenses(String sOfExpenses) {
        this.sOfExpenses = sOfExpenses;
    }

    public String getCategories() {
        return categories;
    }

    public void setCategories(String categories) {
        this.categories = categories;
    }

    public String getKmCode() {
        return kmCode;
    }

    public void setKmCode(String kmCode) {
        this.kmCode = kmCode;
    }

    public String getYyUuid() {
        return yyUuid;
    }

    public void setYyUuid(String yyUuid) {
        this.yyUuid = yyUuid;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getHeaderRow() {
        return HeaderRow;
    }

    public void setHeaderRow(String headerRow) {
        HeaderRow = headerRow;
    }

    public String getSskId() {
        return sskId;
    }

    public void setSskId(String sskId) {
        this.sskId = sskId;
    }

    public Long gethId() {
        return hId;
    }

    public void sethId(Long hId) {
        this.hId = hId;
    }

    public String getHdate() {
        return hdate;
    }

    public void setHdate(String hdate) {
        this.hdate = hdate;
    }

    public String getMoneyColumns() {
        return moneyColumns;
    }

    public void setMoneyColumns(String moneyColumns) {
        this.moneyColumns = moneyColumns;
    }

    public String getNameColumn() {
        return nameColumn;
    }

    public void setNameColumn(String nameColumn) {
        this.nameColumn = nameColumn;
    }

    public String getCodeColumn() {
        return codeColumn;
    }

    public void setCodeColumn(String codeColumn) {
        this.codeColumn = codeColumn;
    }

    public String getDepartmentColumn() {
        return departmentColumn;
    }

    public void setDepartmentColumn(String departmentColumn) {
        this.departmentColumn = departmentColumn;
    }

    public String getNumberColumn() {
        return numberColumn;
    }

    public void setNumberColumn(String numberColumn) {
        this.numberColumn = numberColumn;
    }

    public String getMoneyColumn() {
        return moneyColumn;
    }

    public void setMoneyColumn(String moneyColumn) {
        this.moneyColumn = moneyColumn;
    }

    public String getDateColumn() {
        return dateColumn;
    }

    public void setDateColumn(String dateColumn) {
        this.dateColumn = dateColumn;
    }


    @Override
    public String toString() {
        return "ActSuppliesImportCleaning{" +
                "id='" + id + '\'' +
                ", sskId='" + sskId + '\'' +
                ", hId='" + hId + '\'' +
                ", nameColumn='" + nameColumn + '\'' +
                ", codeColumn='" + codeColumn + '\'' +
                ", departmentColumn='" + departmentColumn + '\'' +
                ", numberColumn='" + numberColumn + '\'' +
                ", moneyColumn='" + moneyColumn + '\'' +
                ", dateColumn='" + dateColumn + '\'' +
                '}';
    }
}
